@@ -1,7 +1,6 @@
 """Variable is a module with basic building blocks."""
 
-from Arbie.Variables.address import Address  # noqa: F401
 from Arbie.Variables.big_number import BigNumber  # noqa: F401
-from Arbie.Variables.pool import Pool, Pools  # noqa: F401
+from Arbie.Variables.pool import Pool, Pools, PoolType  # noqa: F401
 from Arbie.Variables.token import Balance, Balances, Token, Tokens  # noqa: F401
-from Arbie.Variables.trades import ArbitrageOpportunity, Trade  # noqa: F401
+from Arbie.Variables.trades import Trade  # noqa: F401
